#!perl -T

use strict;
use warnings;

use Test::More;

use File::Spec;
use FindBin;
use Config;
use Cwd ();

plan tests => 3;

my ( $script_dir, $script, $script_options, $cmd, $output );

{
    my ( @candidate_dirs );

    foreach my $startdir ( Cwd::cwd(), $FindBin::Bin )
    {
        push @candidate_dirs,
            File::Spec->catdir( $startdir, '..', 'script' ),
            File::Spec->catdir( $startdir, 'script' );
    }

    @candidate_dirs = grep { -d $_ } @candidate_dirs;

    plan skip_all => ( 'unable to find script dir relative to bin: ' .
        $FindBin::Bin . ' or cwd: ' . Cwd::cwd() )
        unless @candidate_dirs;

    $script_dir = $candidate_dirs[ 0 ];
}

$script = File::Spec->catfile( $script_dir, 'benchmark_template_engines' );

#  Untaint stuff so -T doesn't complain.
delete @ENV{qw(PATH IFS CDPATH ENV BASH_ENV)};   # Make %ENV safer
#  We trust their Cwd info and so forth.
$script =~ /^(.*)$/;
$script = $1;
$script_options = '';

ok( ( -e $script ), 'benchmark_template_engines found' );
ok( ( -x $script ), 'benchmark_template_engines is executable' );

$cmd = "${script}${script_options} --nofeatures --featurematrix";
{
    local $ENV{ PERL5LIB } = join( $Config{ path_sep } || ':', @INC );
    diag( "Testing script with command: $cmd\n" .
        "And PERL5LIB: $ENV{PERL5LIB}" );
    $output = `$cmd`;
}

like( $output, qr/^--- (Engine errors|Feature Matrix)/,
    'script compiles ok' );
